function y = ambientHighFreq(N)
% ambientHighFreq - noise generation function
% 
% This function creates random noise with a 17 dB decrease in power per
% octave. 
% 
% y = ambientHighFreq(N)
% 
% Input:
% N - number of samples in the returning random noise array
% 
% Output:
% y - an array of N random variables with decreasing power by frequency
% 
% Last modified 09.12.2014 by
% Frank Hetland & Leo Hauge

% define the length of the vector
% ensure that the M is even
if rem(N,2)
    M = N+1;
else
    M = N;
end

% generate white noise with sigma = 1, mu = 0
x = randn(1, M);

% FFT
X = fft(x);

% prepare a vector for 1/(f^2) multiplication
NumUniquePts = M/2 + 1;
n = 1:NumUniquePts;
n = n.^(sqrt(17/20)); % Found approx by plotting. -17 dB per decade

% multiplicate the left half of the spectrum so the power spectral density
% is inversely proportional to the frequency by factor 1/(f^2), i.e. the
% amplitudes are inversely proportional to 1/f
X(1:NumUniquePts) = X(1:NumUniquePts)./n;

% prepare a right half of the spectrum - a copy of the left one,
% except the DC component and Nyquist frequency - they are unique
X(NumUniquePts+1:M) = real(X(M/2:-1:2)) -1i*imag(X(M/2:-1:2));

% IFFT
y = ifft(X);

% prepare output vector y
y = real(y(1, 1:N));

% normalise
y = y./max(abs(y));

end