function [RL,phaseChange] = reflectionLoss(handles)
% reflectionLoss - function for producing reflection loss
%
% This function computes the reflection loss in dB for 3 cases
%
% [RL,phaseChange] = reflectionLoss(handles)
%
% Input:
% handles - object where:
% handles.class1.Rx - Receiver position relative transmitter
% handles.settings.c0 - Sound speed
% handles.settings.carrierF - Carrier frequency
% handles.class1.dist - Distance for the line of sight
% handles.settings.reflectionCase - An iteger choosing type of reflection
%
% Output:
% RL - Reflection loss in dB
% phaseChange - determine if odd number of reflections
%
% Comments:
% All numbering of equations in the code are obtained from Hovem's book
% Marine Acoustics and can be found there with the corresponding numbering.
%
% Last modified 09.12.2014 by
% Frank Hetland & Leo Hauge



% Output:
% RL   - reflection loss based on critical angle and bottom sediment
%
% Last modified 29.09.2014 by
% Frank Hetland

Rx = handles.class1.Rx;
% c0 = handles.settings.c0;
f = handles.settings.carrierF;
dist = handles.class1.dist;
w = 2*pi*f;
typeOfReflection = handles.settings.reflectionCase;




% Find number of reflections to iterate through
[width,row] = size(dist);
% Empty matrix for inserting reflection loss in dB, is returned by fucntion
RL = zeros(width,row);
% Matrix to validate if the phase is changed by reflections
phaseChange = ones(width,row);


% if sound speed in bottom is larger than sound speed in water
% if (c0(end)<c1)
for m = 1:width
    %         i = i+1;
    for n = 1:row
        if (m == 1) % when rays first hit the surface
            
            % find number of seabed reflections
            numRefBed = floor(n/2); 
            
            % find number of surface reflections
            numRefSur = ceil(n/2);
            
            % Assuming mirror sources, 180 degrees phase change
            changePhase = rem(numRefSur,2);
            if (changePhase == 1)
                % odd number of reflections
                phaseChange(m,n)= -1;
            end
            
        else % rays hit bottom first
            
            % find number of seabed reflections
            numRefBed = ceil(n/2); 
            
            % find number of surface reflections
            numRefSur = floor(n/2);
            
            % Assuming mirror sources, 180 degrees phase change
            changePhase = rem(numRefSur,2);
            if (changePhase == 1)
                % odd number of reflections
                phaseChange(m,n)= -1;
            end
        end
        
        
        
        % angle of ray in water/ GRAZING ANGLE
        theta0 = acos(Rx(2)/dist(m,n));
        
        switch typeOfReflection
                %% First case
            case 1 % Water/Sand (Porous media)
                K_s   = 3.8*10^10;
                K_f   = 2.15*10^9;
                K_r   = 0.6*10^9;
                My_r  = 0.6*10^9;
                Rho_s = 2500;       % density sand
                Rho_f = 1000;     % density water
                Phi   = 0.37;       % portion of porosity
                A_p   = 3.5*10^-5;
                Eta   = 1*10^-3;    % Viscosity
                B     = 0.23*10^-10;%, 0.23*10^-10];
                Alpha = 1.25;%, 1.25];

                
                % From eq. 16.15
                L = (K_f*(K_s -K_r ))/(Phi*(K_s -K_f));
                
                % 16.16
                C = (L*K_s)/(K_s+L);
                
                % 16.17
                M = C*K_s/(K_s-K_r);
                
                % 16.18
                K = K_r+(C^2)/M;
                
                % inline between 16.19 and 16.20
                H = (K+(4/3)*My_r);
                
                % 16.32
                Rho = Phi*Rho_f+(1-Phi)*Rho_s;
                
                % 16.60
                Rho_c = Alpha*Rho_f/Phi;
                
                % 16.30
                c_p0 = sqrt(K_f/Rho_f);
                
                % 16.21
                c_s = sqrt(My_r/Rho);
                
                % From 16.62 and 16.64
                X = A_p*sqrt(w*Rho_f/Eta);
                T_X = -exp(3i*pi/4)*besselj(1,X*exp(3i*pi/4))/besselj(0,X*exp(3i*pi/4));
                F_X = 1/4*X*T_X/(1-2*T_X/(1i*X));
                
                syms kappa % solve determinant for matrix eq. 16.72
                % complex wavenumber
                A = [H*(kappa^2)-Rho*(w^2), Rho_f*(w^2)-C*(kappa^2);...
                    C*(kappa^2)-Rho_f*(w^2), Rho_c*(w^2)-M*(kappa^2)+...
                    (1i*w*Eta*F_X)/(B)];
                
                kappa = solve(det(A),kappa);
                kappa = double(kappa);
                
                kappa_1 = kappa(2);
                kappa_2 = kappa(1);
                
                
                kappa_0 = w/c_p0;
                
                % 16.92
                m_1 = (kappa_1^2*K-w^2*Rho)/(kappa_1^2*C-w^2*Rho_f);
                m_2 = (kappa_2^2*K-w^2*Rho)/(kappa_2^2*C-w^2*Rho_f);
                
                % 16.86
                sinus_0 = sqrt(1-(cos(theta0)));
                sinus_1 = sqrt(1-(kappa_0/kappa_1*cos(theta0)));
                sinus_2 = sqrt(1-(kappa_0/kappa_2*cos(theta0)));
                
                
                % 16.102
                a = (kappa_0*sinus_1*(1-m_1)*K_f*(K-C-m_2*C+m_2*M));
                b = kappa_1*sinus_0*(m_2-m_1)*(K*M-C^2);
                s1 = a/b;
                % 16.103
                a = (kappa_0*sinus_2*(1-m_2)*K_f*(K-C-m_1*C+m_1*M));
                b = kappa_2*sinus_0*(m_1-m_2)*(K*M-C^2);
                s2 = a/b;
                % 16.110, 16.115, 16.116
                Rp = (1-s1-s2)/(1+s1+s2);
                Rp = Rp^numRefBed;
                RL(m,n) = -20*log10(abs(Rp));
                
            case 2
                %% Second case
                % Given parameters
                c_p0 = 1500;
                p_p0 = 1000;
                a_p0 = 0;
                
                % Clay/mud layer
                c_p1 = 2000;
                p_p1 = 2000;
                a_p1 = 0.5;
                
                % some hard rock, gneiss or granite
                c_p2 = 5500;
                p_p2 = 2700;
                a_p2 = 0.5;
                c_s2 = 2500;
                a_s2 = 0.5;
                p_s2 = 2700;
                
                % layer thickness [m]
                d_1 = 5;

                %  2.50 & 15.34 & 15.35
                c_p01 = c_p0*(1-1i*a_p0/(2*pi*8.6859));
                y_p0 = w/c_p01*sin(theta0);
                
                c_p11 = c_p1*(1-1i*a_p1/(2*pi*8.6859));
                sinus1 = sqrt(1-(c_p11/c_p0*cos(theta0))^2);
                
                
                y_p1 = w/c_p11*sinus1;
                c_p21 = c_p2*(1-1i*a_p2/(2*pi*8.6859));
                sinus2 = sqrt(1-(c_p21/c_p0*cos(theta0))^2);
                theta1 = asin(sinus2);
                
                y_p2 = w/c_p21*sinus2;
                c_s21 = c_s2*(1-1i*a_s2/(2*pi*8.6859));
                sinus3 = sqrt(1-(c_s21/c_p0*cos(theta0))^2);
                theta2 = asin(sinus3);
                y_s2 = w/c_s21*sinus3;
                % 15.45
                Z_p1 = w*p_p1/y_p1;
                Z_p2 = w*p_p2/y_p2;
                Z_s2 = w*p_s2/y_s2;
                
                r_12 = (Z_p2*(cos(2*theta2)^2) + Z_s2*(sin(2*theta2)^2)-Z_p1)/...
                    (Z_p2*(cos(2*theta2)^2) + Z_s2*(sin(2*theta2)^2)+Z_p1);
                
                % 5.11 & 15.46
                r_01 = (p_p1*y_p0-y_p1*p_p0)./...
                    (p_p1*y_p0+y_p1*p_p0);
                
                Rp = (r_01+r_12*exp(2i*y_p1*d_1))/(1+r_01*r_12*exp(2i*y_p1*d_1));
                
                Rp = Rp^numRefBed;
                RL(m,n) = -20*log10(abs(Rp));

            case 3
                %% Third Case
                % Total reflection
                RL(m,n) = -20*log10(1);
        end
    end
end
end


